@@ -7,9 +7,11 @@ language being tested)
 import os
 import unittest
 
-from jupyter_client.kernelspec import KernelSpecManager, NoSuchKernel
+from jupyter_client.kernelspec import NoSuchKernel
+
 import jupyter_kernel_test as jkt
 
+
 class IRKernelTests(jkt.KernelTests):
     kernel_name = "ir"
 
@@ -26,23 +28,27 @@ class IRKernelTests(jkt.KernelTests):
 
     code_hello_world = 'print("hello, world")'
 
-    completion_samples = [
-        {
-            'text': 'zi',
-            'matches': {'zip'},
-        },
-    ] if os.name != 'nt' else []  # zip is not available on Windows
+    completion_samples = (
+        [
+            {
+                "text": "zi",
+                "matches": {"zip"},
+            },
+        ]
+        if os.name != "nt"
+        else []
+    )  # zip is not available on Windows
 
-    complete_code_samples = ['1', "print('hello, world')", "f <- function(x) {x*2}"]
+    complete_code_samples = ["1", "print('hello, world')", "f <- function(x) {x*2}"]
     incomplete_code_samples = ["print('hello", "f <- function(x) {x"]
 
     code_generate_error = "raise"
 
     code_display_data = [
-        {'code': "plot(iris)", 'mime': "image/png"},
-        {'code': "1+2+3", "mime": "text/plain" }
+        {"code": "plot(iris)", "mime": "image/png"},
+        {"code": "1+2+3", "mime": "text/plain"},
     ]
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
